@@ -1,7 +1,7 @@
 import platform, os
 
 
-def replace_sys_path(path: str):
+def replace_sys_path(path: str) -> str:
     """
     转windows路径分隔符
     :param path:
@@ -13,7 +13,7 @@ def replace_sys_path(path: str):
         return path
 
 
-def get_path_by_relative(relative_path: str):
+def get_path_by_relative(relative_path: str) -> str:
     """
     根据相对路径，获取绝对路径
     :param relative_path:
